
#include <avr/io.h>               // Pripojenie kninice pre vstupno/vstupn opercie AVR
#include <util/delay.h>           // Pripojenie kninice pre oneskorenia


#define latchPin PD5              // Definovanie pinu pre latch (lon register)
#define clockPin PD6              // Definovanie pinu pre hodinov signl
#define dataPin PD4               // Definovanie pinu pre dtov signl

#define LSBFIRST 1                // Defincia poradia bitov
#define MSBFIRST 1                // Defincia poradia bitov (tto premenn sa v programe nepouva)



int bitOrder;                    // Premenn pre poradie bitov (LSBFIRST alebo MSBFIRST)
int hodnota;                     // Premenn pre ukladanie hodnt posuvnho registra

void shiftOut() {                // Defincia funkcie pre posvanie dt na posuvn register
    int i;                       

    for (i = 0; i < 8; i++)  {   
        if (bitOrder == LSBFIRST) {    
            if (hodnota & (1 << i)) {  // Ak je i-t bit v hodnote zapnut
                PORTD |= (1 << dataPin);  // Zapn dtov pin
            } else {                     // Inak
                PORTD &= ~(1 << dataPin); // Vypn dtov pin
            }
        } else {                       
            if (hodnota & (1 << (7 - i))) {  // Ak je (7 - i)-t bit v hodnote zapnut
                PORTD |= (1 << dataPin);      // Zapn dtov pin
            } else {                         // Inak
                PORTD &= ~(1 << dataPin);     // Vypn dtov pin
            }
        }

        // Toggle clock pin to shift data
        PORTD |= (1 << clockPin);       // Nastavi hodinov pin na vysok rove
        PORTD &= ~(1 << clockPin);      // Nastavi hodinov pin na nzku rove
    }
}

void updateShiftRegister() {         
    PORTD &= ~(1 << latchPin);       // Nastavi pin latch na nzku rove

    // Shift out data
    shiftOut(dataPin, clockPin, LSBFIRST);  // Posun dta na posuvn register

    PORTD |= (1 << latchPin);         // Nastavi pin latch na vysok rove
}

int main(void) {                   
    DDRD |= (1 << latchPin) | (1 << dataPin) | (1 << clockPin);  // Nastavi piny ako vstupn

    while (1) {                       
        hodnota = 0b11100000;         // Nastavi poiaton hodnotu na 0b11100000 (prv 3 LED zapnut)
        for (int i = 0; i < 8; i++) { // Cyklus pre kad bit
            updateShiftRegister();    // Aktualizova hodnoty na posuvnom registri
            hodnota = hodnota >> 1;   // Posun hodnotu o 1 bit doprava
            _delay_ms(200);           // Oneskorzenie 200 ms
        }
        hodnota = 0b00000111;         // Nastavi hodnotu na 0b00000111 (posledn 3 LED zapnut)
        for (int i = 0; i < 8; i++) { // Cyklus pre kad bit
            updateShiftRegister();    // Aktualizova hodnoty na posuvnom registri
            hodnota = hodnota << 1;   // Posun hodnotu o 1 bit doava
            _delay_ms(200);           // Oneskorzenie 200 ms
        }
    }

    return 0;                         // Nvratov hodnota
}
